@@ -1,7 +1,7 @@
 #' @docType package
 #' @name MazamaSpatialUtils
 #' @title Mazama Science spatial data and utility functions.
-#' @description This package contains code to convert various spatial datasets into .RData files 
+#' @description This package contains code to convert various spatial datasets into .RData files
 #' with uniformly named identifiers including:
 #' \itemize{
 #' \item{ countryCode -- ISO 3166-1 alpha-2}
@@ -12,10 +12,10 @@
 #' \item{ latitude -- degrees North}
 #' \item{ area -- m^2}
 #' }
-#' The parameters listed above will be found in the @@data slot of each spatial 
-#' dataset whose source data has an equivalent field. The only field guaranteed 
+#' The parameters listed above will be found in the @@data slot of each spatial
+#' dataset whose source data has an equivalent field. The only field guaranteed
 #' to exist in every dataset is \code{countryCode}.
-#' 
+#'
 #' The following additional standards are applied during the data conversion process:
 #' \itemize{
 #' \item{ all spatial data are converted to a purely geographic projection (\code{CRS("+proj=longlat +ellps=GRS80 +datum=NAD83 +no_defs"}) }
@@ -25,52 +25,14 @@
 #' \item{ parameters may be added to the @@data dataframe }
 #' \item{ latitude and longitude of polygon centroids may be added }
 #' }
-#' 
+#'
 #' Utility functions allow users to determine the country, state, county and timezones
 #' associated with a set of locations, e.g. environmental monitoring sites.
-#' 
+#'
 #' The uniformity of identifiers in the spatial datasets also makes it easy to generate maps
 #' with data from any dataset that uses standard ISO codes for countries or states.
 NULL
 
-#' @docType data
-#' @keywords datasets
-#' @name SimpleCountriesEEZ
-#' @title World country EEZ polygons 
-#' @format A SpatialPolygonsDataFrame with 261 elements and 6 columns of data.
-#' @description SimpleCountriesEEZ is a simplified world borders dataset with a  
-#' 200 mile coastal buffer corresponding to Exclusive Economic Zones, suitable for 
-#' quick spatial searches. This dataset is distributed with the package and is used by
-#' default whenever a dataset with country polygons is required.
-#' @details This dataset is equivalent to EEZCountries but with fewer columns of data.
-#' @seealso convertEEZCountries
-NULL
-
-#' @docType data
-#' @keywords datasets
-#' @name SimpleCountries
-#' @title World country polygons
-#' @format A SpatialPolygonsDataFrame with 246 elements and 7 columns of data.
-#' @description SimpleCountries is a simplified world borders dataset suitable for global maps
-#' and quick spatial searches. This dataset is distributed with the package and is used by
-#' default whenever a dataset with country polygons is required.
-#' @details This dataset is equivalent to TMWorldBordersSimple but with fewer columns of data.
-#' @seealso convertTMWorldBordersSimple
-NULL
-
-
-#' @docType data
-#' @keywords datasets
-#' @name SimpleTimezones
-#' @title World timezone polygons
-#' @format A SpatialPolygonsDataFrame with 1106 elements and 6 columns of data.
-#' @description SimpleTimezones is a simplified world timezones dataset suitable for global maps
-#' and quick spatial searches. This dataset is distributed with the package and is used by
-#' default whenever a dataset with timezone polygons is required.
-#' @details This dataset is a simplified version of WorldTimezones.
-#' @seealso convertWorldTimezones
-NULL
-
 
 # ----- Internal Package State -------------------------------------------------
 
@@ -85,7 +47,7 @@ spatialEnv$dataDir <- NULL
 #' @description This package maintains an internal directory location which users can set
 #' using \code{setSpatialDataDir()}. All package functions use this directory whenever datasets
 #' are created or loaded.
-#' 
+#'
 #' The default setting when the package is loaded is \code{getwd()}.
 #' @seealso getSpatialDataDir
 #' @seealso setSpatialDataDir
@@ -101,16 +63,17 @@ NULL
 #' @seealso setSpatialDataDir
 getSpatialDataDir <- function() {
   if (is.null(spatialEnv$dataDir)) {
-    stop('No data directory found. Please set a data directory with setSpatialDataDir("YOUR_DATA_DIR").',call.=FALSE)
+    stop('No data directory found. Please set a data directory with setSpatialDataDir("YOUR_DATA_DIR").',
+         call. = FALSE)
   } else {
-    return(spatialEnv$dataDir)    
+    return(spatialEnv$dataDir)
   }
 }
 
 #' @keywords environment
 #' @export
 #' @title Set package data directory
-#' @param dataDir directory where spatial datasets are created
+#' @param dataDir Directory where spatial datasets are created.
 #' @description Sets the package data directory where spatial data is located.
 #' If the directory does not exist, it will be created.
 #' @return Silently returns previous value of data directory.
@@ -134,7 +97,7 @@ setSpatialDataDir <- function(dataDir) {
 #' @keywords internal
 #' @export
 #' @title Remove package data directory
-#' @description Resets the package data dir to NULL. Used for internal testing. 
+#' @description Resets the package data dir to NULL. Used for internal testing.
 #' @return Silently returns previous value of data directory.
 #' @seealso SpatialDataDir
 #' @seealso getSpatialDataDir
@@ -150,8 +113,8 @@ removeSpatialDataDir <- function() {
 #' @keywords conversion
 #' @export
 #' @title Convert from ISO2 to ISO3 country codes
-#' @param countryCodes vector of country codes to be converted
-#' @description Converts a vector of ISO 3166-1 alpha-2 codes to the 
+#' @param countryCodes Vector of ISO 3166-1 alpha-2 country codes.
+#' @description Converts a vector of ISO 3166-1 alpha-2 codes to the
 #' corresponding ISO 3166-1 alpha-3 codes.
 #' @return A vector of ISO3 country codes
 iso2ToIso3 <- function(countryCodes) {
@@ -164,15 +127,15 @@ iso2ToIso3 <- function(countryCodes) {
     )
     return(iso3Codes)
   } else {
-    stop('countryCodes must be all ISO 3166-1 alpha-2', call.=FALSE)
+    stop('countryCodes must be all ISO 3166-1 alpha-2', call. = FALSE)
   }
 }
 
 #' @keywords conversion
 #' @export
 #' @title Convert from ISO3 to ISO2 country codes
-#' @param countryCodes vector of country codes to be converted
-#' @description Converts a vector of ISO 3166-1 alpha-3 codes to the 
+#' @param countryCodes Vector of ISO 3166-1 alpha-3 codes.
+#' @description Converts a vector of ISO 3166-1 alpha-3 codes to the
 #' corresponding ISO 3166-1 alpha-2 codes.
 #' @return A vector of ISO2 country codes
 iso3ToIso2 <- function(countryCodes) {
@@ -185,15 +148,15 @@ iso3ToIso2 <- function(countryCodes) {
     )
     return(iso2Codes)
   } else {
-    stop('countryCodes must be all ISO 3166-1 alpha-3', call.=FALSE)
+    stop('countryCodes must be all ISO 3166-1 alpha-3', call. = FALSE)
   }
 }
 
 #' @keywords conversion
 #' @export
 #' @title Convert country codes to country names
-#' @param countryCodes vector of country codes to be converted
-#' @description Converts a vector of ISO 3166-1 alpha-2 codes to the 
+#' @param countryCodes Vector of ISO 3166-1 alpha-2 country codes.
+#' @description Converts a vector of ISO 3166-1 alpha-2 codes to the
 #' corresponding English names.
 #' @return A vector of English country names or NA.
 codeToCountry <- function(countryCodes) {
@@ -207,8 +170,8 @@ codeToCountry <- function(countryCodes) {
 #' @keywords conversion
 #' @export
 #' @title Convert country names to country codes
-#' @param countryNames vector of country names to be converted
-#' @description Converts a vector of English country names to the corresponding 
+#' @param countryNames Vector of English language country names.
+#' @description Converts a vector of English country names to the corresponding
 #' ISO 3166-1 alpha-2 codes.
 #' @return A vector of ISO 3166-1 alpha-2 codes or NA.
 countryToCode <- function(countryNames) {
@@ -222,69 +185,69 @@ countryToCode <- function(countryNames) {
 #' @keywords conversion
 #' @export
 #' @title Convert state codes to state nnames
-#' @param stateCodes vector of state codes to be converted
-#' @param countryCodes ISO-3166-1 alpha-2 country codes the state might be found in
-#' @param dataset name of dataset containing state-level identifiers
-#' @description Converts a vector of ISO 3166-2 alpha-2 state codes to the 
+#' @param stateCodes Vector of state codes.
+#' @param countryCodes Vector of ISO-3166-1 alpha-2 country codes the state might be found in.
+#' @param dataset Name of dataset containing state-level identifiers.
+#' @description Converts a vector of ISO 3166-2 alpha-2 state codes to the
 #' corresponding English names.
-#' @details For this function to work, you must first run 
+#' @details For this function to work, you must first run
 #' \code{initializeSpatialData()} to
 #' download, convert and install the necessary spatial data.
 #' @return A vector of English state names or NA.
 #' @seealso convertNaturalEarthAdm1
 codeToState <- function(
-  stateCodes, 
+  stateCodes,
   countryCodes = NULL,
   dataset = "NaturalEarthAdm1"
 ) {
-  
+
   # Sanity check
   if ( !exists(dataset) ) {
     stop('Missing database. Please loadSpatialData("', dataset, '")',
          call. = FALSE)
   }
-  
+
   SPDF <- get(dataset)
-  
+
   # Remove NA state codes
   stateTable <- SPDF@data[!is.na(SPDF@data$stateCode),]
-  
+
   # Filter by countryCodes to make searching faster
-  if (!is.null(countryCodes)) 
+  if (!is.null(countryCodes))
     stateTable <- stateTable[stateTable$countryCode %in% countryCodes,]
-  
+
   # Test to see if any state codes have duplicate names
   for ( stateCode in stateCodes ) {
-    
+
     repeatCount <- sum(stateTable$stateCode == stateCode)
     if ( repeatCount > 1 ) {
       warning(
         paste0(repeatCount, " states with code '", stateCode, "'. ",
-               "Returning the first instance. ", 
+               "Returning the first instance. ",
                "Please specify countryCode to return the state name from the desired country."))
     }
   }
-  
+
   # Create a vector of state names identified by state code
   allStates <- stateTable$stateName
   names(allStates) <- stateTable$stateCode
-  
+
   return(as.character(allStates[stateCodes]))
-  
+
 }
 
 #' @keywords conversion
 #' @export
 #' @title Convert state names to state codes
-#' @param stateNames state names to be converted
-#' @param countryCodes ISO 3166-2 alpha-2 country codes the state might be found in
-#' @param dataset name of dataset containing state-level identifiers
-#' @description Converts a vector of state names to an ISO 3166-2 two character 
+#' @param stateNames Vector of state names to be converted.
+#' @param countryCodes Vector of ISO 3166-2 alpha-2 country codes the state might be found in.
+#' @param dataset Name of dataset containing state-level identifiers.
+#' @description Converts a vector of state names to an ISO 3166-2 two character
 #' state codes.
-#' @details For this function to work, you must first run 
+#' @details For this function to work, you must first run
 #' \code{initializeSpatialData()} to
 #' download, convert and install the necessary spatial data.
-#' @examples 
+#' @examples
 #' \dontrun{
 #' stateToCode("Washington")
 #' stateToCode("Barcelona")
@@ -293,45 +256,46 @@ codeToState <- function(
 #' @return A vector of ISO 3166-2 codes or NA.
 #' @seealso convertNaturalEarthAdm1
 stateToCode <- function(
-  stateNames, 
+  stateNames,
   countryCodes = NULL,
   dataset = "NaturalEarthAdm1"
 ) {
-  
+
   # Sanity check
   if ( !exists(dataset) ) {
     stop('Missing database. Please loadSpatialData("', dataset, '")',
-         call.=FALSE)
+         call. = FALSE)
   }
-  
+
   SPDF <- get(dataset)
-  
+
   # Remove NA state codes
   stateTable <- SPDF@data[!is.na(SPDF@data$stateCode),]
-  
+
   # Filter by countryCodes to make searching faster
-  if ( !is.null(countryCodes) ) 
+  if ( !is.null(countryCodes) )
     stateTable <- stateTable[stateTable$countryCode %in% countryCodes,]
-  
+
   # Create a vector of state codes identified by name
   allCodes <- stateTable$stateCode
   names(allCodes) <- stateTable$stateName
-  
+
   return(as.character(allCodes[stateNames]))
-  
+
 }
 
-# ----- Simplification  --------------------------------------------------------
+
+# ===== Mapshaper ==============================================================
 
 #' @export
 #' @title Simplify SpatialPolygonsDataFrame
-#' @param SPDF object of class SpatialPolygonsDataFrame
-#' @param keep proportion of points to retain (0-1; default 0.05)
-#' @param ... arguments passed to \code{rmapshaper::ms_simplify()}
+#' @param SPDF Object of class SpatialPolygonsDataFrame.
+#' @param keep Proportion of points to retain (0-1; default 0.05)
+#' @param ... Arguments passed to \code{rmapshaper::ms_simplify()}
 #' @description Simplify a spatial polygons dataframe. This is a convenience
 #' wrapper for \code{rmapshaper::ms_simplify()}
 #' @return A simplified spatial polygons dataframe.
-#' @examples 
+#' @examples
 #' \dontrun{
 #' FR <- subset(SimpleCountries, countryCode == 'FR')
 #' par(mfrow = c(3, 3), mar = c(1, 1, 3, 1))
@@ -344,8 +308,8 @@ stateToCode <- function(
 #' }
 
 simplify <- function(
-  SPDF, 
-  keep = 0.05, 
+  SPDF,
+  keep = 0.05,
   ...
 ) {
   SPDF_simple <- rmapshaper::ms_simplify(SPDF, keep, ...)
@@ -353,20 +317,18 @@ simplify <- function(
 }
 
 
-# ----- Dissolve --------------------------------------------------------------
-
 #' @export
 #' @title Aggregate shapes in a SpatialPolygonsDataFrame
-#' @param SPDF object of class SpatialPolygonsDataFrame
-#' @param field proportion of points to retain (0-1; default 0.05)
-#' @param sum_fields fields to sum
-#' @param copy_fields fields to copy. The first instance of each field will be 
+#' @param SPDF Object of class SpatialPolygonsDataFrame.
+#' @param field Name of the field to dissolve on.
+#' @param sum_fields Names of fields to sum.
+#' @param copy_fields Names of fields to copy. The first instance of each field will be
 #' copied to the aggregated feature
 #' @param ... arguments passed to \code{rmapshaper::ms_dissolve()}
-#' @description Aggregate shapes in a spatial polygons dataframe. This is a 
+#' @description Aggregate shapes in a spatial polygons dataframe. This is a
 #' convenience wrapper for \code{rmapshaper::ms_dissolve()}
 #' @return A spatial polygons dataframe with aggregated shapes.
-#' @examples 
+#' @examples
 #' \donttest{
 #' regions <- dissolve(SimpleCountries, field = "UN_region", sum_fields = "area")
 #' plot(regions)
@@ -374,72 +336,20 @@ simplify <- function(
 #' }
 
 dissolve <- function(
-  SPDF, 
-  field = NULL, 
-  sum_fields = NULL, 
-  copy_fields = NULL, 
+  SPDF,
+  field = NULL,
+  sum_fields = NULL,
+  copy_fields = NULL,
   ...
 ) {
-  
+
   if (!field %in% names(SPDF)) {
     stop(paste0("Field '", field, "' not found."))
   }
   SPDF_dissolved <- rmapshaper::ms_dissolve(SPDF, field, sum_fields, copy_fields, ...)
-  
+
   return(SPDF_dissolved)
-  
+
 }
 
 
-# ----- State codes -----------------------------------------------------------
-
-#' @docType data
-#' @keywords datasets
-#' @name US_stateCodes
-#' @title Dataframe of US state codes
-#' @format A dataframe with 51 rows and 6 columns of data.
-#' @description US_stateCodes contains the following columns of data for the
-#' 50 United States plus the District of Columbia:
-#' \itemize{
-#' \item{\code{stateCode} -- e.g. MT}
-#' \item{\code{stateName} -- e.g. Montana}
-#' \item{\code{adm1_code} -- e.g. USA-3515}
-#' \item{\code{code_hasc} -- e.g. US.MT}
-#' \item{\code{fips} -- e.g. US30}
-#' }
-NULL
-
-
-#' CONUS state codes
-#'
-#' @export
-#' @docType data
-#' @name CONUS
-#' @title CONUS state codes
-#' @format A vector with 49 elements
-#' @description
-#' State codes for the 48 contiguous states +DC that make up the CONtinental US.
-
-CONUS <- c(     "AL","AZ","AR","CA","CO","CT","DE","FL","GA",
-                "ID","IL","IN","IA","KS","KY","LA","ME","MD",
-           "MA","MI","MN","MS","MO","MT","NE","NV","NH","NJ",
-           "NM","NY","NC","ND","OH","OK","OR","PA","RI","SC",
-           "SD","TN","TX","UT","VT","VA","WA","WV","WI","WY",
-           "DC"     )
-
-#' US state codes
-#'
-#' @export
-#' @docType data
-#' @name US_52
-#' @title US state codes
-#' @format A vector with 52 elements
-#' @description
-#' State codes for the 50 states +DC +PR (Puerto Rico).
-
-US_52 <- c("AK","AL","AZ","AR","CA","CO","CT","DE","FL","GA",
-           "HI","ID","IL","IN","IA","KS","KY","LA","ME","MD",
-           "MA","MI","MN","MS","MO","MT","NE","NV","NH","NJ",
-           "NM","NY","NC","ND","OH","OK","OR","PA","RI","SC",
-           "SD","TN","TX","UT","VT","VA","WA","WV","WI","WY",
-           "DC","PR")
